diff --git a/core/includes/bootstrap.inc b/core/includes/bootstrap.inc
index 53fbb992eaabd75e585583b5de09bf0dcd6133a0..36c9c741a8c92d3acaa45504ae331d82f91aa587 100644
--- a/core/includes/bootstrap.inc
+++ b/core/includes/bootstrap.inc
@@ -11,6 +11,8 @@
 use Drupal\Core\Utility\Error;
 use Drupal\Core\StringTranslation\TranslatableMarkup;
 
+// cspell:ignore htkey
+
 /**
  * Error reporting level: display no errors.
  */
diff --git a/core/lib/Drupal/Component/Annotation/Doctrine/DocParser.php b/core/lib/Drupal/Component/Annotation/Doctrine/DocParser.php
index 960c4869ff87f5fb7c011e8c53e0b3a7a484215f..46e452db78ef840a068d1dfac5f4f1b264950393 100644
--- a/core/lib/Drupal/Component/Annotation/Doctrine/DocParser.php
+++ b/core/lib/Drupal/Component/Annotation/Doctrine/DocParser.php
@@ -1004,7 +1004,7 @@ private function Value()
     private function PlainValue()
     {
         if ($this->lexer->isNextToken(DocLexer::T_OPEN_CURLY_BRACES)) {
-            return $this->Arrayx();
+            return $this->ArrayX();
         }
 
         if ($this->lexer->isNextToken(DocLexer::T_AT)) {
@@ -1070,7 +1070,7 @@ private function FieldAssignment()
      *
      * @return array
      */
-    private function Arrayx()
+    private function ArrayX()
     {
         $array = $values = array();
 
diff --git a/core/lib/Drupal/Component/Utility/ToStringTrait.php b/core/lib/Drupal/Component/Utility/ToStringTrait.php
index 9364fadaa873c2d561cb8643a3f1f905ce769bf6..2a77c7b53dfa0be937fb369fdd0e2c627c4aa7cb 100644
--- a/core/lib/Drupal/Component/Utility/ToStringTrait.php
+++ b/core/lib/Drupal/Component/Utility/ToStringTrait.php
@@ -3,7 +3,7 @@
 namespace Drupal\Component\Utility;
 
 /**
- * Wraps __toString in a trait to avoid some fatals.
+ * Wraps __toString in a trait to avoid some fatal errors.
  */
 trait ToStringTrait {
 
diff --git a/core/lib/Drupal/Core/Config/Schema/Element.php b/core/lib/Drupal/Core/Config/Schema/Element.php
index 52be95c977972fa414f048d4f1a46e070b239572..a0c7c11741352056729cf5ebe9712c03e301aaeb 100644
--- a/core/lib/Drupal/Core/Config/Schema/Element.php
+++ b/core/lib/Drupal/Core/Config/Schema/Element.php
@@ -45,7 +45,7 @@ public function getTypedDataManager() {
    *   The typed config manager. This must be an instance of
    *   \Drupal\Core\Config\TypedConfigManagerInterface. If it is not, then this
    *   method will error when assertions are enabled. We can not narrow the
-   *   typehint as this will cause PHP errors.
+   *   type hint as this will cause PHP errors.
    *
    * @return $this
    */
diff --git a/core/lib/Drupal/Core/Form/form.api.php b/core/lib/Drupal/Core/Form/form.api.php
index 572f22003fd114864188f434470b4b95f2d8bf4e..0502ea3239212fd918c0a55ac99244ac72b0d780 100644
--- a/core/lib/Drupal/Core/Form/form.api.php
+++ b/core/lib/Drupal/Core/Form/form.api.php
@@ -50,7 +50,7 @@
  *     all operations have finished, this is passed to callback_batch_finished()
  *     where results may be referenced to display information to the end-user,
  *     such as how many total items were processed.
- *   It is discouraged to typehint this parameter as an array, to allow an
+ *   It is discouraged to type hint this parameter as an array, to allow an
  *   object implement \ArrayAccess to be passed.
  */
 function callback_batch_operation($multiple_params, &$context) {
diff --git a/core/lib/Drupal/Core/TempStore/PrivateTempStore.php b/core/lib/Drupal/Core/TempStore/PrivateTempStore.php
index 1815de4a6298cdf75ab1f90e6227640558e8143b..115ff35ddd8b94feab9e6b627db1045ccc8464f6 100644
--- a/core/lib/Drupal/Core/TempStore/PrivateTempStore.php
+++ b/core/lib/Drupal/Core/TempStore/PrivateTempStore.php
@@ -102,7 +102,7 @@ public function __construct(KeyValueStoreExpirableInterface $storage, LockBacken
    *   The data associated with the key, or NULL if the key does not exist.
    */
   public function get($key) {
-    $key = $this->createkey($key);
+    $key = $this->createKey($key);
     if (($object = $this->storage->get($key)) && ($object->owner == $this->getOwner())) {
       return $object->data;
     }
@@ -132,7 +132,7 @@ public function set($key, $value) {
       }
     }
 
-    $key = $this->createkey($key);
+    $key = $this->createKey($key);
     if (!$this->lockBackend->acquire($key)) {
       $this->lockBackend->wait($key);
       if (!$this->lockBackend->acquire($key)) {
@@ -160,7 +160,7 @@ public function set($key, $value) {
    *   NULL otherwise.
    */
   public function getMetadata($key) {
-    $key = $this->createkey($key);
+    $key = $this->createKey($key);
     // Fetch the key/value pair and its metadata.
     $object = $this->storage->get($key);
     if ($object) {
@@ -184,7 +184,7 @@ public function getMetadata($key) {
    *   Thrown when a lock for the backend storage could not be acquired.
    */
   public function delete($key) {
-    $key = $this->createkey($key);
+    $key = $this->createKey($key);
     if (!$object = $this->storage->get($key)) {
       return TRUE;
     }
@@ -211,7 +211,7 @@ public function delete($key) {
    * @return string
    *   The unique key for the user.
    */
-  protected function createkey($key) {
+  protected function createKey($key) {
     return $this->getOwner() . ':' . $key;
   }
 
diff --git a/core/misc/cspell/dictionary.txt b/core/misc/cspell/dictionary.txt
index 29a20c77a993f8cf8e14f19a3191ad8977d97c41..97b7928067c8124d4ff06f42afc5a0fc8aeef701 100644
--- a/core/misc/cspell/dictionary.txt
+++ b/core/misc/cspell/dictionary.txt
@@ -9,7 +9,6 @@ adminforms
 afterclose
 aftercreate
 ahah
-ajaxcallback
 ajaxing
 allwords
 alphadecimal
@@ -20,7 +19,6 @@ applix
 archiver
 archivers
 arrakis
-arrayx
 arrowrefresh
 arrowreturn
 arrowreturnthick
@@ -163,7 +161,6 @@ controlgroup
 conv
 corge
 cpio
-createkey
 createrole
 createuser
 crema
@@ -274,7 +271,6 @@ falsey
 falsish
 fapi
 fastcgi
-fatals
 favourite
 favstar
 fcgi
@@ -336,7 +332,6 @@ hoglet
 hookname
 hosters
 hrefs
-htkey
 htmlcorrector
 httpheader
 httplug
@@ -350,7 +345,6 @@ idekey
 iframes
 iframeupload
 imagecache
-imagecreatefrom
 imagetextalternative
 indexname
 inited
@@ -426,7 +420,6 @@ mank
 maryjane
 matchout
 mathematica
-maxage
 maximumred
 maxlifetime
 maynot
@@ -798,9 +791,6 @@ testcase
 testcontent
 testcontextawareblock
 testdialog
-testfilter
-testfunc
-testfunction
 testgroups
 testkey
 testlogger
@@ -852,7 +842,6 @@ troopal
 truecolor
 twistie
 twocol
-typehint
 tzid
 uids
 ulwa
diff --git a/core/modules/content_moderation/src/Form/ContentModerationConfigureEntityTypesForm.php b/core/modules/content_moderation/src/Form/ContentModerationConfigureEntityTypesForm.php
index d13ce9301c5d0a08bf1f0233289e5bdb4c752da9..427ee1fd99cce600be6590bb48122791e718814c 100644
--- a/core/modules/content_moderation/src/Form/ContentModerationConfigureEntityTypesForm.php
+++ b/core/modules/content_moderation/src/Form/ContentModerationConfigureEntityTypesForm.php
@@ -161,14 +161,14 @@ public function buildForm(array $form, FormStateInterface $form_state, WorkflowI
       '#button_type' => 'primary',
       '#value' => $this->t('Save'),
       '#ajax' => [
-        'callback' => [$this, 'ajaxcallback'],
+        'callback' => [$this, 'ajaxCallback'],
       ],
     ];
     $form['actions']['cancel'] = [
       '#type' => 'button',
       '#value' => $this->t('Cancel'),
       '#ajax' => [
-        'callback' => [$this, 'ajaxcallback'],
+        'callback' => [$this, 'ajaxCallback'],
       ],
     ];
 
diff --git a/core/modules/file/src/Plugin/migrate/process/d6/FieldFile.php b/core/modules/file/src/Plugin/migrate/process/d6/FieldFile.php
index eb378a09699a97b51d2d7ab1367c3983c878cc95..6845b154f4eb59e1d0e057dbfd2e5627f3b2dc37 100644
--- a/core/modules/file/src/Plugin/migrate/process/d6/FieldFile.php
+++ b/core/modules/file/src/Plugin/migrate/process/d6/FieldFile.php
@@ -73,7 +73,7 @@ public function transform($value, MigrateExecutableInterface $migrate_executable
     // means the file referenced by the current field item did not migrate for
     // some reason -- file migration is notoriously brittle -- and we do NOT
     // want to send invalid file references into the field system (it causes
-    // fatals), so return an empty item instead.
+    // fatal errors), so return an empty item instead.
     $lookup_result = $this->migrateLookup->lookup('d6_file', [$value['fid']]);
     if ($lookup_result) {
       return [
diff --git a/core/modules/page_cache/tests/src/Functional/PageCacheTest.php b/core/modules/page_cache/tests/src/Functional/PageCacheTest.php
index 9824e196252a14015847517d84effbf2e603b5a6..6d3f618a5d979202b0079c1df6cabfed260bc694 100644
--- a/core/modules/page_cache/tests/src/Functional/PageCacheTest.php
+++ b/core/modules/page_cache/tests/src/Functional/PageCacheTest.php
@@ -268,7 +268,7 @@ public function testPageCache() {
     // Until bubbling of max-age up to the response is supported, verify that
     // a custom #cache max-age set on an element does not affect page max-age.
     $this->drupalLogout();
-    $this->drupalGet('system-test/cache_maxage_page');
+    $this->drupalGet('system-test/cache_max_age_page');
     $this->assertSession()->responseHeaderEquals('Cache-Control', 'max-age=300, public');
   }
 
diff --git a/core/modules/rest/src/RequestHandler.php b/core/modules/rest/src/RequestHandler.php
index a435e3ef0cc33ba851fdc594cfb67c1442c83900..6af909d78434ed5a0cdcd5604bf201ba0f0197b5 100644
--- a/core/modules/rest/src/RequestHandler.php
+++ b/core/modules/rest/src/RequestHandler.php
@@ -247,7 +247,7 @@ protected function createArgumentResolver(RouteMatchInterface $route_match, $uns
     // methods historically receive the unserialized request body as the N+1th
     // method argument, where N is the number of route parameters specified on
     // the accompanying route. To be able to use the argument resolver, which is
-    // not based on position but on name and typehint, specify commonly used
+    // not based on position but on name and type hint, specify commonly used
     // names here. Similarly, those methods receive the original stored object
     // as the first method argument.
 
diff --git a/core/modules/system/src/Plugin/ImageToolkit/GDToolkit.php b/core/modules/system/src/Plugin/ImageToolkit/GDToolkit.php
index 8ba8e9c82f19477fddfc49d6c17af09c3d982a66..977280cc764c39653e93d0a5a7f75358677b781e 100644
--- a/core/modules/system/src/Plugin/ImageToolkit/GDToolkit.php
+++ b/core/modules/system/src/Plugin/ImageToolkit/GDToolkit.php
@@ -15,7 +15,7 @@
 use Psr\Log\LoggerInterface;
 use Symfony\Component\DependencyInjection\ContainerInterface;
 
-// cspell:ignore rrggbb
+// cspell:ignore imagecreatefrom rrggbb
 
 /**
  * Defines the GD2 toolkit for image manipulation within Drupal.
diff --git a/core/modules/system/tests/modules/error_test/error_test.routing.yml b/core/modules/system/tests/modules/error_test/error_test.routing.yml
index ad961520da0f32cfb6082c1a086da23c0f07761f..de1c0770d5d14c14367b96198703bf010bad654e 100644
--- a/core/modules/system/tests/modules/error_test/error_test.routing.yml
+++ b/core/modules/system/tests/modules/error_test/error_test.routing.yml
@@ -5,10 +5,10 @@ error_test.generate_warnings:
   requirements:
     _access: 'TRUE'
 
-error_test.generate_fatals:
-  path: '/error-test/generate-fatals'
+error_test.generate_fatal_errors:
+  path: '/error-test/generate-fatal-errors'
   defaults:
-    _controller: '\Drupal\error_test\Controller\ErrorTestController::generateFatals'
+    _controller: '\Drupal\error_test\Controller\ErrorTestController::generateFatalErrors'
   requirements:
     _access: 'TRUE'
 
diff --git a/core/modules/system/tests/modules/system_test/src/Controller/SystemTestController.php b/core/modules/system/tests/modules/system_test/src/Controller/SystemTestController.php
index 6b6ef7686f5efcbb34910ad123dddd88981057f3..6107402e6a9f20d12a267c09132ad079cd78a8d4 100644
--- a/core/modules/system/tests/modules/system_test/src/Controller/SystemTestController.php
+++ b/core/modules/system/tests/modules/system_test/src/Controller/SystemTestController.php
@@ -263,7 +263,7 @@ public function system_test_cache_tags_page() {
   /**
    * Set cache max-age on the returned render array.
    */
-  public function system_test_cache_maxage_page() {
+  public function system_test_cache_max_age_page() {
     $build['main'] = [
       '#cache' => ['max-age' => 90],
       'message' => [
diff --git a/core/modules/system/tests/modules/system_test/system_test.routing.yml b/core/modules/system/tests/modules/system_test/system_test.routing.yml
index 74b836e2592c44757fd388a85ba3ba615f1c8e8e..78135051a071c448d6a5625bccb106295b47ac07 100644
--- a/core/modules/system/tests/modules/system_test/system_test.routing.yml
+++ b/core/modules/system/tests/modules/system_test/system_test.routing.yml
@@ -76,10 +76,10 @@ system_test.cache_tags_page:
   requirements:
     _access: 'TRUE'
 
-system_test.cache_maxage_page:
-  path: '/system-test/cache_maxage_page'
+system_test.cache_max_age_page:
+  path: '/system-test/cache_max_age_page'
   defaults:
-    _controller: '\Drupal\system_test\Controller\SystemTestController::system_test_cache_maxage_page'
+    _controller: '\Drupal\system_test\Controller\SystemTestController::system_test_cache_max_age_page'
   requirements:
     _access: 'TRUE'
 
diff --git a/core/modules/system/tests/modules/twig_extension_test/src/TwigExtension/TestExtension.php b/core/modules/system/tests/modules/twig_extension_test/src/TwigExtension/TestExtension.php
index 753c90f2f4b5cf6761c2b17ba16b1d7547cb24d5..1c32550d9570978c66de225ef9429e537f8750fe 100644
--- a/core/modules/system/tests/modules/twig_extension_test/src/TwigExtension/TestExtension.php
+++ b/core/modules/system/tests/modules/twig_extension_test/src/TwigExtension/TestExtension.php
@@ -18,14 +18,14 @@ class TestExtension extends AbstractExtension {
    *   A key/value array that defines custom Twig functions. The key denotes the
    *   function name used in the tag, e.g.:
    *   @code
-   *   {{ testfunc() }}
+   *   {{ custom_function() }}
    *   @endcode
    *
    *   The value is a standard PHP callback that defines what the function does.
    */
   public function getFunctions() {
     return [
-      'testfunc' => new TwigFunction('testfunc', ['Drupal\twig_extension_test\TwigExtension\TestExtension', 'testFunction']),
+      'custom_function' => new TwigFunction('custom_function', ['Drupal\twig_extension_test\TwigExtension\TestExtension', 'testFunction']),
     ];
   }
 
@@ -36,14 +36,14 @@ public function getFunctions() {
    *   A key/value array that defines custom Twig filters. The key denotes the
    *   filter name used in the tag, e.g.:
    *   @code
-   *   {{ foo|testfilter }}
+   *   {{ foo|test_filter }}
    *   @endcode
    *
    *   The value is a standard PHP callback that defines what the filter does.
    */
   public function getFilters() {
     return [
-      'testfilter' => new TwigFilter('testfilter', ['Drupal\twig_extension_test\TwigExtension\TestExtension', 'testFilter']),
+      'test_filter' => new TwigFilter('test_filter', ['Drupal\twig_extension_test\TwigExtension\TestExtension', 'testFilter']),
     ];
   }
 
diff --git a/core/modules/system/tests/modules/twig_extension_test/templates/twig_extension_test.filter.html.twig b/core/modules/system/tests/modules/twig_extension_test/templates/twig_extension_test.filter.html.twig
index 981874fcdc7469e5840dc5ea7b8cb4020c9581ad..04ffb2b7f2819a830056cab4d0b10d6ae566d7b7 100644
--- a/core/modules/system/tests/modules/twig_extension_test/templates/twig_extension_test.filter.html.twig
+++ b/core/modules/system/tests/modules/twig_extension_test/templates/twig_extension_test.filter.html.twig
@@ -1,5 +1,5 @@
-<div class="testfilter">
-  {{ message|testfilter }}
+<div class="test-filter">
+  {{ message|test_filter}}
 </div>
 <div>
   {{ safe_join_items|safe_join('<br/>') }}
diff --git a/core/modules/system/tests/modules/twig_extension_test/templates/twig_extension_test.function.html.twig b/core/modules/system/tests/modules/twig_extension_test/templates/twig_extension_test.function.html.twig
index 76e870f34d7574d20ecd9adb767c55b0d6f162fd..1bf9c210a7198f8bf90f9d9461ff2c63d609eeb2 100644
--- a/core/modules/system/tests/modules/twig_extension_test/templates/twig_extension_test.function.html.twig
+++ b/core/modules/system/tests/modules/twig_extension_test/templates/twig_extension_test.function.html.twig
@@ -1,7 +1,7 @@
-<div class="testfunction">
-  {{ testfunc(1) }}
+<div class="test-function">
+  {{ custom_function(1) }}
 </div>
 
-<div class="testfunction">
-  {{ testfunc(0) }}
+<div class="test-function">
+  {{ custom_function(0) }}
 </div>
diff --git a/core/tests/Drupal/FunctionalTests/Bootstrap/UncaughtExceptionTest.php b/core/tests/Drupal/FunctionalTests/Bootstrap/UncaughtExceptionTest.php
index cba5665cf14e1e6605bf3d6074b70791739a72ca..bb741b0738551c80b7f6d2522f10286699154719 100644
--- a/core/tests/Drupal/FunctionalTests/Bootstrap/UncaughtExceptionTest.php
+++ b/core/tests/Drupal/FunctionalTests/Bootstrap/UncaughtExceptionTest.php
@@ -98,7 +98,7 @@ public function testUncaughtFatalError() {
       '@message' => 'Drupal\error_test\Controller\ErrorTestController::Drupal\error_test\Controller\{closure}(): Argument #1 ($test) must be of type array, string given, called in ' . \Drupal::root() . '/core/modules/system/tests/modules/error_test/src/Controller/ErrorTestController.php on line 65',
       '%function' => 'Drupal\error_test\Controller\ErrorTestController->Drupal\error_test\Controller\{closure}()',
     ];
-    $this->drupalGet('error-test/generate-fatals');
+    $this->drupalGet('error-test/generate-fatal-errors');
     $this->assertSession()->statusCodeEquals(500);
     $message = new FormattableMarkup('%type: @message in %function (line ', $fatal_error);
     $this->assertSession()->responseContains((string) $message);
diff --git a/core/tests/Drupal/FunctionalTests/BrowserTestBaseTest.php b/core/tests/Drupal/FunctionalTests/BrowserTestBaseTest.php
index f1da9fc46f093ed4a2277e49b792cbfdd8584f72..5de919c221d4d387dcefa7bc3d88a83ee829177c 100644
--- a/core/tests/Drupal/FunctionalTests/BrowserTestBaseTest.php
+++ b/core/tests/Drupal/FunctionalTests/BrowserTestBaseTest.php
@@ -13,6 +13,8 @@
 use PHPUnit\Framework\ExpectationFailedException;
 use Symfony\Component\HttpFoundation\Request;
 
+// cspell:ignore htkey
+
 /**
  * Tests BrowserTestBase functionality.
  *
@@ -524,7 +526,7 @@ public function testProfileModules() {
   /**
    * Tests the protections provided by .htkey.
    */
-  public function testHtkey() {
+  public function testHtKey() {
     // Remove the Simpletest private key file so we can test the protection
     // against requests that forge a valid testing user agent to gain access
     // to the installer.
diff --git a/core/tests/Drupal/KernelTests/Core/Image/ToolkitGdTest.php b/core/tests/Drupal/KernelTests/Core/Image/ToolkitGdTest.php
index adfb42294764b27c989e53854b3a3a5e15c8e25e..3e1b4ab31e114b3cceabdd0a3da83abdcb77436d 100644
--- a/core/tests/Drupal/KernelTests/Core/Image/ToolkitGdTest.php
+++ b/core/tests/Drupal/KernelTests/Core/Image/ToolkitGdTest.php
@@ -7,6 +7,8 @@
 use Drupal\Core\Image\ImageInterface;
 use Drupal\KernelTests\KernelTestBase;
 
+// cspell:ignore imagecreatefrom
+
 /**
  * Tests for the GD image toolkit.
  *
diff --git a/core/tests/Drupal/Tests/Component/ProxyBuilder/ProxyBuilderTest.php b/core/tests/Drupal/Tests/Component/ProxyBuilder/ProxyBuilderTest.php
index 1105b3f1934dbc7171eb516a0e7ee185b39e1867..ed1f19a68686d9f293c48ebb2ed0a35de89dedf7 100644
--- a/core/tests/Drupal/Tests/Component/ProxyBuilder/ProxyBuilderTest.php
+++ b/core/tests/Drupal/Tests/Component/ProxyBuilder/ProxyBuilderTest.php
@@ -285,8 +285,8 @@ public static function testMethod($parameter)
    * @covers ::buildParameter
    * @covers ::buildMethodBody
    */
-  public function testBuildWithNullableSelfTypehint() {
-    $class = 'Drupal\Tests\Component\ProxyBuilder\TestServiceNullableTypehintSelf';
+  public function testBuildWithNullableSelfTypeHint() {
+    $class = 'Drupal\Tests\Component\ProxyBuilder\TestServiceNullableTypeHintSelf';
 
     $result = $this->proxyBuilder->build($class);
 
@@ -296,9 +296,9 @@ public function testBuildWithNullableSelfTypehint() {
 /**
  * {@inheritdoc}
  */
-public function typehintSelf(?\Drupal\Tests\Component\ProxyBuilder\TestServiceNullableTypehintSelf $parameter): ?\Drupal\Tests\Component\ProxyBuilder\TestServiceNullableTypehintSelf
+public function typeHintSelf(?\Drupal\Tests\Component\ProxyBuilder\TestServiceNullableTypeHintSelf $parameter): ?\Drupal\Tests\Component\ProxyBuilder\TestServiceNullableTypeHintSelf
 {
-    return $this->lazyLoadItself()->typehintSelf($parameter);
+    return $this->lazyLoadItself()->typeHintSelf($parameter);
 }
 
 EOS;
@@ -438,9 +438,9 @@ public function complexMethod(string $parameter, callable $function, TestService
 
 }
 
-class TestServiceNullableTypehintSelf {
+class TestServiceNullableTypeHintSelf {
 
-  public function typehintSelf(?self $parameter): ?self {
+  public function typeHintSelf(?self $parameter): ?self {
     return NULL;
   }
 
diff --git a/core/tests/Drupal/Tests/Core/Access/CsrfTokenGeneratorTest.php b/core/tests/Drupal/Tests/Core/Access/CsrfTokenGeneratorTest.php
index ea71f5e23ed29f272031e4d275ba2f8e0dc473bd..011a8f2eba8e5133f799f7b764df359b7541b82f 100644
--- a/core/tests/Drupal/Tests/Core/Access/CsrfTokenGeneratorTest.php
+++ b/core/tests/Drupal/Tests/Core/Access/CsrfTokenGeneratorTest.php
@@ -142,8 +142,8 @@ public function testValidate() {
   public function testValidateParameterTypes($token, $value) {
     $this->setupDefaultExpectations();
 
-    // The following check might throw PHP fatals and notices, so we disable
-    // error assertions.
+    // The following check might throw PHP fatal errors and notices, so we
+    // disable error assertions.
     set_error_handler(function () {
       return TRUE;
     });
diff --git a/core/tests/Drupal/Tests/Core/Config/StorageCopyTraitTest.php b/core/tests/Drupal/Tests/Core/Config/StorageCopyTraitTest.php
index aa30d1028f0089aa679b0a49558c1c8cee942cfc..2dc0b1fd0cacce117e50abacba25e7edaf84e1a8 100644
--- a/core/tests/Drupal/Tests/Core/Config/StorageCopyTraitTest.php
+++ b/core/tests/Drupal/Tests/Core/Config/StorageCopyTraitTest.php
@@ -174,7 +174,7 @@ public function testWithInvalidConfiguration() {
 class TestStorage extends MemoryStorage {
 
   /**
-   * Provides a setter to bypass the array typehint on ::write().
+   * Provides a setter to bypass the array type hint on ::write().
    *
    * This method allows us to create invalid configurations. The method
    * ::write() only allows values of the type array.
diff --git a/core/tests/Drupal/Tests/Scripts/TestSiteApplicationTest.php b/core/tests/Drupal/Tests/Scripts/TestSiteApplicationTest.php
index 3c91d151c03687a75a522d987ba26c69f341154e..c49af3f1c2c6f1a54fe7b3e1c34386a6fab6446a 100644
--- a/core/tests/Drupal/Tests/Scripts/TestSiteApplicationTest.php
+++ b/core/tests/Drupal/Tests/Scripts/TestSiteApplicationTest.php
@@ -13,6 +13,8 @@
 use Symfony\Component\Process\PhpExecutableFinder;
 use Symfony\Component\Process\Process;
 
+// cspell:ignore htkey
+
 /**
  * Tests core/scripts/test-site.php.
  *
diff --git a/core/modules/filter/tests/src/Unit/FilterHtmlTest.php b/core/modules/filter/tests/src/Unit/FilterHtmlTest.php
index d020f1d0197a69dd1b04eb0fea83001be955cd5b..7733948534cfec480c8bf46fcd54c2c826537e81 100644
--- a/core/modules/filter/tests/src/Unit/FilterHtmlTest.php
+++ b/core/modules/filter/tests/src/Unit/FilterHtmlTest.php
@@ -42,12 +42,12 @@ protected function setUp(): void {
    * @param string $expected
    *   The expected output string.
    */
-  public function testfilterAttributes($html, $expected) {
+  public function testFilterAttributes($html, $expected) {
     $this->assertSame($expected, $this->filter->filterAttributes($html));
   }
 
   /**
    * Provides data for testfilterAttributes.
    *
    * @return array
    *   An array of test data.
@@ -42,12 +42,12 @@ protected function setUp(): void {
 
   /**
-   * Provides data for testfilterAttributes.
+   * Provides data for testFilterAttributes.
    *
    * @return array
diff --git a/core/modules/system/tests/modules/error_test/src/Controller/ErrorTestController.php b/core/modules/system/tests/modules/error_test/src/Controller/ErrorTestController.php
index d2845e6d5ac0a12444c87a08779837115b8c5313..1201083762600d6722a40f4cb4f87422f96bb03a 100644
--- a/core/modules/system/tests/modules/error_test/src/Controller/ErrorTestController.php
+++ b/core/modules/system/tests/modules/error_test/src/Controller/ErrorTestController.php
@@ -56,9 +56,9 @@ public function generateWarnings($collect_errors = FALSE) {
   }
 
   /**
    * Generate fatals to test the error handler.
    */
-  public function generateFatals() {
+  public function generateFatalErrors() {
     $function = function (array $test) {
     };
 
@@ -56,9 +56,9 @@ public function generateWarnings($collect_errors = FALSE) {
 
   /**
-   * Generate fatals to test the error handler.
+   * Generate fatal errors to test the error handler.
    */
diff --git a/core/tests/Drupal/Tests/Component/Utility/ArgumentsResolverTest.php b/core/tests/Drupal/Tests/Component/Utility/ArgumentsResolverTest.php
index c20e800a7f9d9996b3267c4213c408f52d936ad5..9f7004e4d27e8bde274c786ca393c752053eaee1 100644
--- a/core/tests/Drupal/Tests/Component/Utility/ArgumentsResolverTest.php
+++ b/core/tests/Drupal/Tests/Component/Utility/ArgumentsResolverTest.php
@@ -124,11 +124,11 @@ public function testGetArgumentOrder() {
   }
 
   /**
    * Tests getArgument() with a wildcard parameter with no typehint.
    *
    * Without the typehint, the wildcard object will not be passed to the callable.
    */
-  public function testGetWildcardArgumentNoTypehint() {
+  public function testGetWildcardArgumentNoTypeHint() {
     $a = $this->getMockBuilder('\Drupal\Tests\Component\Utility\Test1Interface')->getMock();
     $wildcards = [$a];
     $resolver = new ArgumentsResolver([], [], $wildcards);
@@ -140,12 +140,12 @@ public function testGetWildcardArgumentNoTypehint() {
   }
 
   /**
    * Tests getArgument() with a named parameter with no typehint and a value.
    *
    * Without the typehint, passing a value to a named parameter will still
    * receive the provided value.
    */
-  public function testGetArgumentRouteNoTypehintAndValue() {
+  public function testGetArgumentRouteNoTypeHintAndValue() {
     $scalars = ['route' => 'foo'];
     $resolver = new ArgumentsResolver($scalars, [], []);
 
@@ -124,11 +124,11 @@ public function testGetArgumentOrder() {
 
   /**
-   * Tests getArgument() with a wildcard parameter with no typehint.
+   * Tests getArgument() with a wildcard parameter with no type hint.
    *
@@ -124,11 +124,11 @@ public function testGetArgumentOrder() {
    *
-   * Without the typehint, the wildcard object will not be passed to the callable.
+   * Without the type hint, the wildcard object will not be passed to the callable.
    */
@@ -140,12 +140,12 @@ public function testGetWildcardArgumentNoTypehint() {
 
   /**
-   * Tests getArgument() with a named parameter with no typehint and a value.
+   * Tests getArgument() with a named parameter with no type hint and a value.
    *
@@ -140,12 +140,12 @@ public function testGetWildcardArgumentNoTypehint() {
    *
-   * Without the typehint, passing a value to a named parameter will still
+   * Without the type hint, passing a value to a named parameter will still
    * receive the provided value.
    */